==> deepin-voice-recorder_1.3.6.1.orig.tar.gz: deepin-voice-recorder-1.3.6.1/translations/deepin-voice-recorder_nl.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="nl" version="2.1">
<context>
    <name>FileView</name>
    <message>
        <location filename="../src/file_view.cpp" line="59"/>
        <source>Rename</source>
        <translation>Hernoemen</translation>
    </message>
    <message>
        <location filename="../src/file_view.cpp" line="61"/>
        <source>Display in file manager</source>
        <translation>Weergeven in bestandsbeheerder</translation>
    </message>
    <message>
        <location filename="../src/file_view.cpp" line="63"/>
        <source>Move to trash</source>
        <translation>Verplaatsen naar prullenbak</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/main_window.cpp" line="53"/>
        <source>New recording</source>
        <translation>Nieuwe opname</translation>
    </message>
    <message>
        <location filename="../src/main_window.cpp" line="55"/>
        <source>Open saved directory</source>
        <translation>Open opgeslagen map</translation>
    </message>
    <message>
        <location filename="../src/main_window.cpp" line="57"/>
        <source>About</source>
        <translation>Over</translation>
    </message>
    <message>
        <location filename="../src/main_window.cpp" line="59"/>
        <source>Help</source>
        <translation>Help</translation>
    </message>
    <message>
        <location filename="../src/main_window.cpp" line="61"/>
        <source>Exit</source>
        <translation>Sluiten</translation>
    </message>
    <message>
        <location filename="../src/main_window.cpp" line="168"/>
        <source>Deepin Voice Recorder is a beautiful and easy to use voice recording application with simple design. It supports visual recording, recording playback, recording list management and other functions.</source>
        <translation>Deepin Voice Recorder is een nette en handige applicatie voor stemopnames, met een intuïtief ontwerp. Deepin Voice Recorder ondersteunt visuele feedback bij het opnemen, makkelijk afspelen en beheren van opnames en nog veel meer.</translation>
    </message>
    <message>
        <location filename="../src/main_window.cpp" line="180"/>
        <source>Deepin Voice Recorder</source>
        <translation>Deepin Voice Recorder</translation>
    </message>
    <message>
        <location filename="../src/main_window.cpp" line="181"/>
        <source>Version</source>
        <translation>Versie</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/main.cpp" line="45"/>
        <source>Deepin Voice Recorder</source>
        <translation>Deepin Voice Recorder</translation>
    </message>
</context>
<context>
    <name>RecordPage</name>
    <message>
        <location filename="../src/record_page.cpp" line="55"/>
        <location filename="../src/record_page.cpp" line="219"/>
        <source>New recording</source>
        <translation>Nieuwe opname</translation>
    </message>
</context>
<context>
    <name>Utils</name>
    <message>
        <location filename="../src/utils.cpp" line="136"/>
        <source>Recording</source>
        <translation>Aan het opnemen</translation>
    </message>
</context>
</TS>

==> deepin-voice-recorder_1.3.9.orig.tar.gz: deepin-voice-recorder-1.3.9/translations/deepin-voice-recorder_nl.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="nl" version="2.1">
<context>
    <name>FileView</name>
    <message>
        <location filename="../src/file_view.cpp" line="59"/>
        <source>Rename</source>
        <translation>Naam wijzigen</translation>
    </message>
    <message>
        <location filename="../src/file_view.cpp" line="61"/>
        <source>Display in file manager</source>
        <translation>Tonen in bestandsbeheerder</translation>
    </message>
    <message>
        <location filename="../src/file_view.cpp" line="63"/>
        <source>Move to trash</source>
        <translation>Verplaatsen naar prullenbak</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/main_window.cpp" line="53"/>
        <source>New recording</source>
        <translation>Nieuwe opname</translation>
    </message>
    <message>
        <location filename="../src/main_window.cpp" line="55"/>
        <source>Open saved directory</source>
        <translation>Opgeslagen map openen</translation>
    </message>
    <message>
        <location filename="../src/main_window.cpp" line="57"/>
        <source>About</source>
        <translation>Over</translation>
    </message>
    <message>
        <location filename="../src/main_window.cpp" line="59"/>
        <source>Help</source>
        <translation>Hulp</translation>
    </message>
    <message>
        <location filename="../src/main_window.cpp" line="61"/>
        <source>Exit</source>
        <translation>Sluiten</translation>
    </message>
    <message>
        <location filename="../src/main_window.cpp" line="168"/>
        <source>Deepin Voice Recorder is a beautiful and easy to use voice recording application with simple design. It supports visual recording, recording playback, recording list management and other functions.</source>
        <translation>Deepin Geluidsopname is een prachtig ontworpen en eenvoudig te gebruiken applicatie voor stemopnames. Deepin Geluidsopname ondersteunt visuele feedback bij het opnemen, afspelen en beheren van opnames en meer.</translation>
    </message>
    <message>
        <location filename="../src/main_window.cpp" line="180"/>
        <source>Deepin Voice Recorder</source>
        <translation>Deepin Geluidsopname</translation>
    </message>
    <message>
        <location filename="../src/main_window.cpp" line="181"/>
        <source>Version</source>
        <translation>Versie</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/main.cpp" line="45"/>
        <source>Deepin Voice Recorder</source>
        <translation>Deepin Geluidsopname</translation>
    </message>
</context>
<context>
    <name>RecordPage</name>
    <message>
        <location filename="../src/record_page.cpp" line="55"/>
        <location filename="../src/record_page.cpp" line="219"/>
        <source>New recording</source>
        <translation>Nieuwe opname</translation>
    </message>
</context>
<context>
    <name>Utils</name>
    <message>
        <location filename="../src/utils.cpp" line="136"/>
        <source>Recording</source>
        <translation>Bezig met opnemen</translation>
    </message>
</context>
</TS>
